# 0.0.4 - June 17th 2022

## Pre-Release

- This is the pre-release czitools package v0.0.4

# 0.0.5 - June 18th 2022

## Pre-Release

- This is the pre-release czitools package v0.0.5
- License updated